@@ -1,38 +1,45 @@
-use clap::Parser;
+#![cfg(feature = "build-binary")]
+
 use colored::*;
 use std::fs::File;
 use std::io::{self, BufRead, BufReader, Lines, Stdin};
 use std::path::{Path, PathBuf};
+use textwrap::*;
 
 use quick_error::ResultExt;
 
+use clap::{AppSettings, FromArgMatches, IntoApp, Parser};
+
 use untree::*;
 
 fn main() {
+    let app = Args::into_app()
+        .global_setting(AppSettings::DeriveDisplayOrder)
+        .global_setting(AppSettings::NextLineHelp)
+        .setting(AppSettings::DisableHelpSubcommand)
+    //     .bold(Style::Good, true)
+    //     .bold(Style::Warning, true)
+    //     .foreground(Style::Warning, Some(Color::Green))
+        .max_term_width(100);
+
+    let args = Args::from_arg_matches(&app.get_matches()).unwrap();
+
     use Error::*;
-    if let Err(err) = run() {
-        let header = "Error".bold().red();
-        let prefix = "".bold().red();
-        let line = format!("{:═<80}", "").bold().red();
-
-        eprintln!();
-        eprintln!("{header}");
-        eprintln!("{line}");
-
+    if let Err(err) = run(args) {
         match err {
             MissingContext(err) => {
-                eprintln!("Error with unknown context. {err}")
+                print_error("An error occured with unknown context.", err);
             }
             OnStdin(err) => {
-                eprintln!("Error when attempting to read standard input. {err}")
+                print_error("An error occured while attempting to read from standard input.", err);
             }
             OnPath(path, action, err) => {
-                let path = path.to_str().unwrap_or("<unspeakable path>").bold();
+                let path = path.to_str().unwrap_or("<unspeakable>").bold();
                 let action = action.describe(&path);
-                eprintln!("{prefix}Error when attempting to {action}.");
-                eprintln!("{prefix}");
-                eprintln!("{prefix}{err}");
-                eprintln!();
+                print_error(
+                    format!("An error occured while attempting to {action}."),
+                    err,
+                );
             }
         }
 
@@ -40,32 +47,38 @@ fn main() {
     }
 }
 
-fn run() -> Result<()> {
-    let args = Args::parse();
+fn print_error(msg: impl std::fmt::Display, base_err: io::Error) {
+    let msg = format!("{msg}\n\nCause: {base_err}");
+    let width = termwidth();
 
+    let msg = fill(msg.as_str(), width - 4);
+    let msg = indent(msg.as_str(), "    ");
+
+    let header = "ERROR:".bold().red();
+
+    eprintln!();
+    eprintln!("{header}");
+    eprintln!("{}", msg);
+    eprintln!();
+}
+
+fn run(args: Args) -> Result<()> {
     let directory = args.dir.unwrap_or_else(|| "".into());
 
-    let options = UntreeOptions {
-        dry_run: args.dry_run,
-        verbose: args.verbose,
-    };
+    let options = UntreeOptions::new()
+        .dry_run(args.dry_run)
+        .verbose(args.verbose);
 
     let tree_files = &args.tree_files;
 
     if tree_files.is_empty() {
-        eprintln!(
-            "{}",
-            "Reading tree from standard input".red().bold()
-        );
+        eprintln!("{}", "Reading tree from standard input".bold());
         create_tree(&directory, read_stdin(), options).more_context(ReadStdin)
     } else {
         for path in tree_files {
             let filename = path.to_str().unwrap_or("<unspeakable>");
             if filename == "-" {
-                eprintln!(
-                    "{}",
-                    "Reading tree from standard input".red().bold()
-                );
+                eprintln!("{}", "Reading tree from standard input".bold());
                 create_tree(&directory, read_stdin(), options)
                     .more_context(ReadStdin)?;
             } else {
@@ -73,12 +86,12 @@ fn run() -> Result<()> {
                 let lines = read_lines(path)?;
                 eprintln!(
                     "{}",
-                    format!("Reading tree from file '{filename}'").red().bold()
+                    format!("Reading tree from file '{filename}'").bold()
                 );
                 create_tree(&directory, lines, options)
                     .more_context(ReadFile.on(path))?;
             }
-        };
+        }
         Ok(())
     }
 }
@@ -102,7 +115,7 @@ pub struct Args {
     /// Directory to use as the root of the newly generated directory
     /// structure. Uses current working directory if no directory is
     /// specified.
-    #[clap(short, long, parse(from_os_str))]
+    #[clap(short, long("--dir"), parse(from_os_str))]
     pub dir: Option<PathBuf>,
     /// List of files containing trees to be read by untree. If no files are
     /// specified, then the tree is read from standard input.
